@@ -49,7 +49,7 @@ class CfnDataCatalog(
         type: builtins.str,
         description: typing.Optional[builtins.str] = None,
         parameters: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[builtins.str, builtins.str]]] = None,
-        tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]] = None,
+        tags: typing.Optional[typing.Sequence[aws_cdk.core.CfnTag]] = None,
     ) -> None:
         '''Create a new ``AWS::Athena::DataCatalog``.
 
@@ -188,7 +188,7 @@ class CfnDataCatalogProps:
         type: builtins.str,
         description: typing.Optional[builtins.str] = None,
         parameters: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[builtins.str, builtins.str]]] = None,
-        tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]] = None,
+        tags: typing.Optional[typing.Sequence[aws_cdk.core.CfnTag]] = None,
     ) -> None:
         '''Properties for defining a ``AWS::Athena::DataCatalog``.
 
@@ -542,7 +542,7 @@ class CfnWorkGroup(
         description: typing.Optional[builtins.str] = None,
         recursive_delete_option: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         state: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]] = None,
+        tags: typing.Optional[typing.Sequence[aws_cdk.core.CfnTag]] = None,
         work_group_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationProperty"]] = None,
         work_group_configuration_updates: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationUpdatesProperty"]] = None,
     ) -> None:
@@ -1259,7 +1259,7 @@ class CfnWorkGroupProps:
         description: typing.Optional[builtins.str] = None,
         recursive_delete_option: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         state: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]] = None,
+        tags: typing.Optional[typing.Sequence[aws_cdk.core.CfnTag]] = None,
         work_group_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, CfnWorkGroup.WorkGroupConfigurationProperty]] = None,
         work_group_configuration_updates: typing.Optional[typing.Union[aws_cdk.core.IResolvable, CfnWorkGroup.WorkGroupConfigurationUpdatesProperty]] = None,
     ) -> None:
